﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;

namespace DetailsView_NestedLevel
{
    public class NotificationObject : INotifyPropertyChanged
    {
        public void RaisePropertyChanged(string propName)
        {
            if (this.PropertyChanged != null)
                this.PropertyChanged(this, new PropertyChangedEventArgs(propName));
        }
        public event PropertyChangedEventHandler PropertyChanged;
    }

    public class BaseEmployee : NotificationObject
    {
        private int _EmployeeID;
        [Range(1007, 1009, ErrorMessage = "EmployeeID can hold value between 1007 and 1009")]

        public int EmployeeID
        {
            get { return this._EmployeeID; }
            set
            {
                this._EmployeeID = value;
                this.RaisePropertyChanged("EmployeeID");
            }
        }
    }

    public class Employee : BaseEmployee, IDataErrorInfo
    {

        #region private members

        private int _orderId;
        private int _ContactID;
        private DateTime _BirthDate;
        private double _SickLeaveHours;
        private decimal _Salary;
        private ObservableCollection<SalesInfo> _salesDetails;
        private ObservableCollection<OrderInfo> _orderDetails;
        private ObservableCollection<ProductInfo> _productDetails;

        #endregion

        # region public properties

        [Range(10, 107, ErrorMessage = "OrderID can hold value between 10 and 107")]
        public int OrderID
        {
            get { return this._orderId; }
            set
            {
                this._orderId = value;
                this.RaisePropertyChanged("OrderID");
            }
        }


        public int ContactID
        {
            get { return this._ContactID; }
            set
            {
                this._ContactID = value;
                this.RaisePropertyChanged("ContactID");
            }
        }

        public DateTime BirthDate
        {
            get { return this._BirthDate; }
            set
            {
                this._BirthDate = value;
                this.RaisePropertyChanged("BirthDate");
            }
        }

        public double SickLeaveHours
        {
            get { return this._SickLeaveHours; }
            set
            {
                this._SickLeaveHours = value;
                this.RaisePropertyChanged("SickLeaveHours");
            }
        }

        public decimal Salary
        {
            get { return this._Salary; }
            set
            {
                this._Salary = value;
                this.RaisePropertyChanged("Salary");
            }
        }

        private string _city;

        public string City
        {
            get
            {
                return _city;
            }
            set
            {
                _city = value;
                RaisePropertyChanged("City");
            }
        }

        public ObservableCollection<OrderInfo> OrderDetails
        {
            get
            {
                return _orderDetails;
            }
            set
            {
                _orderDetails = value;
                RaisePropertyChanged("OrderDetails");
            }
        }

        public ObservableCollection<SalesInfo> SalesDetails
        {
            get
            {
                return _salesDetails;
            }
            set
            {
                _salesDetails = value;
                RaisePropertyChanged("SalesDetails");
            }
        }


        public ObservableCollection<ProductInfo> ProductDetails
        {
            get
            {
                return _productDetails;
            }
            set
            {
                _productDetails = value;
                RaisePropertyChanged("ProductDetails");
            }
        }




        #endregion


        public string Error
        {
            get
            {
                return null;
            }
        }

        public string this[string columnName]
        {
            get
            {
                if (columnName.Equals("Salary"))
                {
                    if (this.Salary > 5010)
                        return null;
                    else
                        return "Salary sholud have more than 5010";
                }
                return null;
            }
        }

    }
}
